@@ -14,15 +14,17 @@ from bcolz import utils, attrs, array2string
 import itertools
 from collections import namedtuple
 import json
-import os, os.path
+import os
+import os.path
 import shutil
-from .py2help import _inttypes, _strtypes, imap, xrange
+from .py2help import _inttypes, imap, xrange
 
 _inttypes += (np.integer,)
 islice = itertools.islice
 
 ROOTDIRS = '__rootdirs__'
 
+
 class cols(object):
     """Class for accessing the columns on the ctable object."""
 
@@ -38,18 +40,18 @@ class cols(object):
         rootsfile = os.path.join(self.rootdir, ROOTDIRS)
         with open(rootsfile, 'rb') as rfile:
             data = json.loads(rfile.read().decode('ascii'))
-        # JSON returns unicode (?)
+        # JSON returns unicode, but we want plain bytes for Python 2.x
         self.names = [str(name) for name in data['names']]
         # Initialize the cols by instantiating the carrays
-        for name, dir_ in data['dirs'].items():
-            self._cols[str(name)] = bcolz.carray(rootdir=dir_, mode=self.mode)
+        for name in self.names:
+            dir_ = os.path.join(self.rootdir, name)
+            self._cols[name] = bcolz.carray(rootdir=dir_, mode=self.mode)
 
     def update_meta(self):
         """Update metainfo about directories on-disk."""
         if not self.rootdir:
             return
-        dirs = dict((n, o.rootdir) for n,o in self._cols.items())
-        data = {'names': self.names, 'dirs': dirs}
+        data = {'names': self.names}
         rootsfile = os.path.join(self.rootdir, ROOTDIRS)
         with open(rootsfile, 'wb') as rfile:
             rfile.write(json.dumps(data).encode('ascii'))
@@ -82,17 +84,17 @@ class cols(object):
         col = self._cols[name]
         self.update_meta()
         return col
-    
+
     def __str__(self):
         fullrepr = ""
         for name in self.names:
-            fullrepr += "%s : %s" % (name, str(self._cols[name])) 
+            fullrepr += "%s : %s" % (name, str(self._cols[name]))
         return fullrepr
 
     def __repr__(self):
         fullrepr = ""
         for name in self.names:
-            fullrepr += "%s : %s\n" % (name, repr(self._cols[name])) 
+            fullrepr += "%s : %s\n" % (name, repr(self._cols[name]))
         return fullrepr
 
 
@@ -173,7 +175,6 @@ class ctable(object):
         "The size of this object."
         return np.prod(self.shape)
 
-
     def __init__(self, columns=None, names=None, **kwargs):
 
         # Important optional params
@@ -214,7 +215,7 @@ class ctable(object):
 
         # Attach the attrs to this object
         self.attrs = attrs.attrs(self.rootdir, self.mode, _new=_new)
-            
+
         # Cache a structured array of len 1 for ctable[int] acceleration
         self._arr1 = np.empty(shape=(1,), dtype=self.dtype)
 
@@ -230,7 +231,7 @@ class ctable(object):
             if isinstance(columns, np.ndarray):  # ratype case
                 names = list(columns.dtype.names)
             else:
-                names = ["f%d"%i for i in range(len(columns))]
+                names = ["f%d" % i for i in range(len(columns))]
         else:
             if type(names) == tuple:
                 names = list(names)
@@ -258,13 +259,6 @@ class ctable(object):
                     raise ValueError("only unidimensional shapes supported")
         else:
             raise ValueError("`columns` input is not supported")
-        if not (calist or nalist or ratype):
-            # Try to convert the elements to carrays
-            try:
-                columns = [bcolz.carray(col, **kwargs) for col in columns]
-                calist = True
-            except:
-                raise ValueError("`columns` input is not supported")
 
         # Populate the columns
         clen = -1
@@ -285,11 +279,16 @@ class ctable(object):
                 column = bcolz.carray(column, **kwargs)
             elif ratype:
                 column = bcolz.carray(columns[name], **kwargs)
+            else:
+                # Try to convert from a sequence of columns
+                column = bcolz.carray(columns[i], **kwargs)
             self.cols[name] = column
             if clen >= 0 and clen != len(column):
+                if self.rootdir:
+                    shutil.rmtree(self.rootdir)
                 raise ValueError("all `columns` must have the same length")
             clen = len(column)
- 
+
         self.len = clen
 
     def open_ctable(self):
@@ -314,60 +313,60 @@ class ctable(object):
                 os.remove(rootdir)
         os.mkdir(rootdir)
 
-    def append(self, rows):
+    def append(self, cols):
         """
-        append(rows)
+        append(cols)
 
-        Append `rows` to this ctable.
+        Append `cols` to this ctable.
 
         Parameters
         ----------
-        rows : list/tuple of scalar values, NumPy arrays or carrays
+        cols : list/tuple of scalar values, NumPy arrays or carrays
             It also can be a NumPy record, a NumPy recarray, or
             another ctable.
 
         """
 
-        # Guess the kind of rows input
+        # Guess the kind of cols input
         calist, nalist, sclist, ratype = False, False, False, False
-        if type(rows) in (tuple, list):
-            calist = [type(v) for v in rows] == [bcolz.carray for v in rows]
-            nalist = [type(v) for v in rows] == [np.ndarray for v in rows]
+        if type(cols) in (tuple, list):
+            calist = [type(v) for v in cols] == [bcolz.carray for v in cols]
+            nalist = [type(v) for v in cols] == [np.ndarray for v in cols]
             if not (calist or nalist):
                 # Try with a scalar list
                 sclist = True
-        elif isinstance(rows, np.ndarray):
-            ratype = hasattr(rows.dtype, "names")
-        elif isinstance(rows, bcolz.ctable):
+        elif isinstance(cols, np.ndarray):
+            ratype = hasattr(cols.dtype, "names")
+        elif isinstance(cols, bcolz.ctable):
             # Convert int a list of carrays
-            rows = [rows[name] for name in self.names]
+            cols = [cols[name] for name in self.names]
             calist = True
         else:
-            raise ValueError("`rows` input is not supported")
+            raise ValueError("`cols` input is not supported")
         if not (calist or nalist or sclist or ratype):
-            raise ValueError("`rows` input is not supported")
+            raise ValueError("`cols` input is not supported")
 
         # Populate the columns
         clen = -1
         for i, name in enumerate(self.names):
             if calist or sclist:
-                column = rows[i]
+                column = cols[i]
             elif nalist:
-                column = rows[i]
+                column = cols[i]
                 if column.dtype == np.void:
-                    raise ValueError("`rows` elements cannot be of type void")
+                    raise ValueError("`cols` elements cannot be of type void")
                 column = column
             elif ratype:
-                column = rows[name]
+                column = cols[name]
             # Append the values to column
             self.cols[name].append(column)
-            if sclist:
+            if sclist and not hasattr(column, '__len__'):
                 clen2 = 1
             else:
                 clen2 = len(column)
             if clen >= 0 and clen != clen2:
                 raise ValueError(
-                    "all cols in `rows` must have the same length")
+                    "all cols in `cols` must have the same length")
             clen = clen2
         self.len += clen
 
@@ -541,7 +540,7 @@ class ctable(object):
 
         # Check that origin and destination do not overlap
         rootdir = kwargs.get('rootdir', None)
-        if rootdir and self.rootdir and  rootdir == self.rootdir:
+        if rootdir and self.rootdir and rootdir == self.rootdir:
                 raise IOError("rootdir cannot be the same during copies")
 
         # Remove possible unsupported args for columns
@@ -550,9 +549,9 @@ class ctable(object):
         # Copy the columns
         if rootdir:
             # A copy is always made during creation with a rootdir
-            cols = [ self.cols[name] for name in self.names ]
+            cols = [self.cols[name] for name in self.names]
         else:
-            cols = [ self.cols[name].copy(**kwargs) for name in self.names ]
+            cols = [self.cols[name].copy(**kwargs) for name in self.names]
         # Create the ctable
         ccopy = ctable(cols, names, **kwargs)
         return ccopy
@@ -602,7 +601,8 @@ class ctable(object):
         cols = []
         # Remove a possible rootdir argument to prevent copies going to disk
         ckwargs = kwargs.copy()
-        if 'rootdir' in ckwargs: del ckwargs['rootdir']
+        if 'rootdir' in ckwargs:
+            del ckwargs['rootdir']
         for key in names:
             vals = df[key].values  # just a view as a numpy array
             if vals.dtype == np.object:
@@ -614,12 +614,14 @@ class ctable(object):
                 #     maxitemsize = pd.lib.max_len_string_array(vals)
                 #     print "maxitemsize:", maxitesize
                 #     # Convert the view into a carray of Unicode strings
-                #     col = bcolz.carray(vals, dtype='U%d'%maxitemsize, **ckwargs)
+                #     col = bcolz.carray(vals,
+                #                        dtype='U%d' % maxitemsize, **ckwargs)
                 # elif inferred_type == 'string':
                 if inferred_type == 'string':
                     maxitemsize = pd.lib.max_len_string_array(vals)
                     # Convert the view into a carray of regular strings
-                    col = bcolz.carray(vals, dtype='S%d'%maxitemsize, **ckwargs)
+                    col = bcolz.carray(vals, dtype='S%d' %
+                                       maxitemsize, **ckwargs)
                 else:
                     col = vals
                 cols.append(col)
@@ -663,14 +665,19 @@ class ctable(object):
 
         # Read the Table on file
         f = tb.open_file(filepath)
-        t = f.get_node(nodepath)
+        try:
+            t = f.get_node(nodepath)
+        except:
+            f.close()
+            raise
+
         # Use the names in kwargs, or if not there, the names in Table
         if 'names' in kwargs:
             names = kwargs.pop('names')
         else:
             names = t.colnames
         # Collect metadata
-        dtypes = [dt[0] for dt in t.dtype.fields.values()]
+        dtypes = [t.dtype.fields[name][0] for name in names]
         cols = [np.zeros(0, dtype=dt) for dt in dtypes]
         # Create an empty ctable
         ct = ctable(cols, names, **kwargs)
@@ -724,7 +731,8 @@ class ctable(object):
     def tohdf5(self, filepath, nodepath='/ctable', mode='w',
                cparams=None, cname=None):
         """
-        tohdf5(filepath, nodepath='/ctable', mode='w', cparams=None, cname=None)
+        tohdf5(filepath, nodepath='/ctable', mode='w',
+               cparams=None, cname=None)
 
         Write this object into an HDF5 file.
 
@@ -897,7 +905,8 @@ class ctable(object):
             try:
                 dtype = [(name, self[name].dtype) for name in outfields]
             except IndexError:
-                raise ValueError("Some names in `outfields` are not real fields")
+                raise ValueError(
+                    "Some names in `outfields` are not real fields")
 
         buf = np.empty(blen, dtype=dtype)
         nrow = 0
@@ -910,7 +919,6 @@ class ctable(object):
                 nrow = 0
         yield buf[:nrow]
 
-
     def __iter__(self):
         return self.iter(0, self.len, 1)
 
@@ -1042,7 +1050,7 @@ class ctable(object):
         # Slices
         elif type(key) == slice:
             (start, stop, step) = key.start, key.stop, key.step
-            if step and step <= 0 :
+            if step and step <= 0:
                 raise NotImplementedError("step in slice can only be positive")
         # Multidimensional keys
         elif isinstance(key, tuple):
@@ -1075,7 +1083,7 @@ class ctable(object):
                 return np.array([self[i] for i in key], dtype=self.dtype)
             else:
                 raise IndexError(
-                      "arrays used as indices must be integer (or boolean)")
+                    "arrays used as indices must be integer (or boolean)")
         # Column name or expression
         elif type(key) is str:
             if key not in self.names:
@@ -1131,7 +1139,7 @@ class ctable(object):
         # Check if key is a condition actually
         if type(key) is bytes:
             # Convert key into a boolean array
-            #key = self.eval(key)
+            # key = self.eval(key)
             # The method below is faster (specially for large ctables)
             rowval = 0
             for nrow in self.where(key, outcols=["nrow__"]):
@@ -1221,7 +1229,7 @@ class ctable(object):
 
         """
 
-        nbytes, cbytes, ratio = 0, 0, 0.0
+        nbytes, cbytes = 0, 0
         names, cols = self.names, self.cols
         for name in names:
             column = cols[name]
@@ -1247,8 +1255,8 @@ class ctable(object):
         return fullrepr
 
 
-## Local Variables:
-## mode: python
-## tab-width: 4
-## fill-column: 78
-## End:
+# Local Variables:
+# mode: python
+# tab-width: 4
+# fill-column: 78
+# End:
